% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
%                4.3.2011      T. Roeder, Rohde&Schwarz
%
% *************************************************************************

% VISA instrument resource descriptor
  RscID   = 'TCPIP::rssmu200a101485::INSTR';
% RscID   = 'TCPIP::192.168.0.100::INSTR'; 
% RscID   = 'GPIB0::28::INSTR';  

% use VISA interface from National Instruments
  [status, InstrObject] = rs_connect( 'visa', 'ni', RscID );

% use raw socket connection via LAN
% [status, InstrObject] = rs_connect( 'tcpip', 'rssmu200a101485' );

RfLevel = 5.0;                              % RF level in dBm
RfFreq1 = 1.000;                            % start frequency in GHz
RfStep  = 0.025;                            % increment value in GHz
RfFreq2 = 2.000;                            % stop frequency in GHz

RunZero = 0;                                % zero sensor first
                                            % (only required for low power
                                            % levels)
disp( ' ' );
disp( '=== MEASURE POWER ACROSS FREQUENCIES ===' );
disp( ' ' );

if( status<1 )
    disp (['*** Return status from rs_connect() is : ' num2str(status)]);
    return;
end

% read all errors from queue
rs_check_instrument_errors( InstrObject );

[status, Result] = rs_send_query( InstrObject, '*IDN?' );
if( isempty(strfind(Result, 'SMB100A')) && isempty(strfind(Result, 'SMF100A')) && ...
    isempty(strfind(Result, 'SMA100A')) && isempty(strfind(Result, 'SMBV100A')) && ...
    isempty(strfind(Result, 'SMU200A')) && isempty(strfind(Result, 'SMJ100A')) )
    disp( 'Instrument type not supported' );
    delete( InstrObject ); return;
end

% query if sensor is connected to port 1 or 2
%    SENS1 = round sensor connector
%    SENS2 = USB connector
Sensor     = 'SENS1';
SensorRead = 'READ1';
[status, Result] = rs_send_query( InstrObject, [ Sensor ':POW:TYPE?' ] );
if( status<1 ); delete( InstrObject ); return; end; 

if isempty( strfind( Result, 'NRP' ) )
    disp( 'No sensor connected to port 1. Trying port 2.' );
    
    Sensor     = 'SENS2';
    SensorRead = 'READ2';
    [status, Result] = rs_send_query( InstrObject, [ Sensor ':POW:TYPE?' ] );
    if( status<1 ); delete( InstrObject ); return; end; 
    
    if isempty( strfind( Result, 'NRP' ) )
        disp( 'No sensor connected to port 2' );
        delete( InstrObject ); return;
    end
    
end

disp( ['Sensor Type: ' Result] );

% turn RF output off
[status, Result] = rs_send_query( InstrObject, 'OUTP:STAT OFF; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% set to dBm
[status, Result] = rs_send_query( InstrObject, [ Sensor ':UNIT:POW DBM; *OPC?' ] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% couple to path A for automatic frequency correction
[status, Result] = rs_send_query( InstrObject, [ Sensor ':POW:SOURCE A; *OPC?' ] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% set to auto filter
[status, Result] = rs_send_query( InstrObject, [ Sensor ':POW:FILT:TYPE AUTO; *OPC?' ] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

if( RunZero )
    disp ('Zeroing...');
    [status, Result] = rs_send_query( InstrObject, [ Sensor ':POW:ZERO; *OPC?' ] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end
end

% set RF level
[status, Result] = rs_send_query( InstrObject, ['SOUR:POW:LEV ' num2str(RfLevel) ' dBm; *OPC?'] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% set RF start frequency
[status, Result] = rs_send_query( InstrObject, ['SOUR:FREQ ' num2str(RfFreq1) ' GHz; *OPC?'] );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% turn RF on
[status, Result] = rs_send_query( InstrObject, 'OUTP:STAT ON; *OPC?' );
if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end

% check for any instrument errors
status = rs_check_instrument_errors( InstrObject );
if( status<0 ); delete( InstrObject ); return; end

% loop across frequencies
iNum      = 1;
PowerData = zeros( 1+(RfFreq2-RfFreq1)/RfStep,1 );

disp( '  Frequency       Level' );
disp( '-------------------------' );
for Freq = RfFreq1:RfStep:RfFreq2
    
    % set RF frequency
    [status, Result] = rs_send_query( InstrObject, ['SOUR:FREQ ' num2str(Freq) ' GHz; *OPC?'] );
    if( status<0 || Result(1)~='1' ); delete( InstrObject ); return; end
    
    % pause the execution for a little while to allow 
    % for GUI updates on the instrument
    pause( 0.1 );
    
    % read sensor power (activate it if required)
    [status, Result] = rs_send_query( InstrObject, [ SensorRead ':POW?' ] );
    if( status<1 )
        delete( InstrObject );
        disp (['Return status from rs_send_query() is : ' num2str(status)]);
        return;
    end

    % The average power is the first value in the result string
    AveragePower      = strtok( Result, ',' );
    PowerData( iNum ) = RfLevel - str2double( AveragePower );
    Sign = ' ';
    if PowerData( iNum )<0
        Sign = '-';
    end
    disp( [ '  ' num2str( Freq, '%5.3f' ) ' GHz    ' Sign num2str( abs( PowerData( iNum ) ), '%6.2f dB' ) ] );
    iNum = iNum + 1;
    
end

% turn RF off
[status, Result] = rs_send_query( InstrObject, 'OUTP:STAT OFF; *OPC?' );
if( status<0 ); delete( InstrObject ); return; end

% set back to RF start frequency
[status, Result] = rs_send_query( InstrObject, ['SOUR:FREQ ' num2str(RfFreq1) ' GHz; *OPC?'] );
if( status<0 ); delete( InstrObject ); return; end

% plot result
F=RfFreq1:RfStep:RfFreq2;
plot (F,PowerData,... 
                '--rs', 'LineWidth',2,...
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','blue',...
                'MarkerSize',3);
title( 'Attenuation versus Frequency','Color','blue' );
xlabel( 'Frequency/GHz' );
ylabel( 'Attenuation/dB' );
grid on;

% clear variables
clear;

disp( '  ' );

return;


