% function rs_nrpz_get_error
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function gets the name for an error code.
% @param  libname                     The name of the library.
% @param  session                     The session ID.
% @param  errorcode                   Numeric error code.
%%
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, ErrorText] = rs_nrpz_get_error( libname, session, errorcode )  

    Status = 0;

    z = zeros( 1, 512, 'int8' );
    pReturnText   = libpointer( 'int8Ptr', z );

    % error code
    if ( errorcode )

        % if the session is valid we evaluate the error further
        if( session>0 )
            
            [DummyErr, Text] = calllib( libname, 'rsnrpz_error_message',...
                session, errorcode, pReturnText );
            
            ErrorText = sprintf( '%d,%s', errorcode, char(Text) );
            
            Status = 1;
            return;
            
        end
        
        ErrorText = [ num2str( errorcode ) ',Unknown Error. No session created.' ];
        Status = 1;
        return;
        
    end
    
    ErrorText = '0,No Error.';
    Status = 1;
    
 return;

