% function rs_nrpz_init 
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function opens the sensor connection.
% @param  libname                     The name of the library.
% @param  sensorname                  The sensor that shall be opened or
%                                     '*' for any available sensor.
%%
% @return session                     Session number created when opening
%                                     the sensor connection.
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, session] = rs_nrpz_init( libname, sensorname )  

    Status = 0;

    % create pointers for return values
    pNRPSession   = libpointer( 'uint32Ptr', 0 );

    % Set the resource descriptor for the USB Power Sensor  
    % '*' uses the first available sensor. It is also possible
    % to provide the USB resources string here, using the format
    % 'USB::<vendorID>::<productID>::<serial number>'
    % The vendor ID for R&S instruments is 0x0AAD
    % The product ID depends on the sensor. See the driver documentation
    % or Power Viewer Plus manual for details.
    pSensorName = libpointer( 'int8Ptr', [int8( sensorname ) 0] );

    % Open the sensor connection. No other application must access this
    % sensor at the same time.
    [err, p8, session] = calllib( libname, 'rsnrpz_init', pSensorName,...
                                  1, 1, pNRPSession );
    if( err<0 || session==0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;
    
return;

