% function rs_nrpz_read_measurement
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function starts a measurement and waits for its completion.
% @param  libname                     The name of the library.
% @param  session                     The session ID.
%%
% @return Result                      Sensor reading
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, Result] = rs_nrpz_read_measurement( libname, session )  

    Status = 0;

    % The sensor opened through rsnrpz_init() always uses channel 1.
    channel = 1;
    
    pMeas = libpointer( 'doublePtr', 0 );   

    % Run one single measurement and return the value.
    % 5000 = 5 sec timeout
    [err, Result] = calllib( libname, 'rsnrpz_meass_readMeasurement', ....
        session, channel, 5000, pMeas );
    
    if( err<0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;
   
return;

